pub struct Autoload {
pub classmap: Vec<String>,
pub exclude_from_classmap: Vec<String>,
pub files: Vec<String>,
pub psr_0: HashMap<String, AutoloadPsr0value>,
pub psr_4: HashMap<String, AutoloadPsr4value>,
}Fields
classmap: Vec<String>This is an array of paths that contain classes to be included in the class-map generation process
exclude_from_classmap: Vec<String>This is an array of patterns to exclude from autoload classmap generation. (e.g. “exclude-from-classmap”: [“/test/”, “/tests/”, “/Tests/”]“]
files: Vec<String>This is an array of files that are always required on every request
psr_0: HashMap<String, AutoloadPsr0value>This is an object of namespaces (keys) and the directories they can be found in (values, can be arrays of paths) by the autoloader
psr_4: HashMap<String, AutoloadPsr4value>This is an object of namespaces (keys) and the PSR-4 directories they can map to (values, can be arrays of paths) by the autoloader